name: "oranges_classflaw"
revision: 10
description: "model orange_flaws_64x64_3c_2f_3o_20170206: 0 negative, 1 stalks, 2 flaws; stalk/flaw overlap control 0.7"

stages {
  name: "item"
  type: SOURCE_CUSTOM
#  custom_param {
#    proxy: "test:ConcatCustomSource"
#    args: "oranges_segmentation.apl"
#  }
}

# Bounding-box resizing
stages {
  name: "item_normalized"
  type: RESIZE
  input: "item"
  resize_param {
    width: 240
    height: 240
  }
}

# CNN fully-convolutional
stages {
  name: "flaw_all"
  type: NEURAL_NETWORK
  input: "item_normalized"
  neural_network_param {
    deploy: "orange_models/orange_flaws_64x64_3c_2f_3o_20170206/deploy.prototxt"
    model: "orange_models/orange_flaws_64x64_3c_2f_3o_20170206/net.caffemodel"
    scale: 0.00390625

    fully_deploy: "orange_models/orange_flaws_64x64_3c_2f_3o_20170206/deploy_fully.prototxt"
    fully_subst_layers: "fc4 => fc4-conv, fc5 => fc5-conv, fc6 => fc6-conv"
    fully_cluster: true

    gpu: true
    encrypted: false
  }
}

# Exclude all the classes except the stalks
stages {
  name: "stalk_filter"
  type: CLASS_FILTER
  input: "flaw_all"
  class_filter_param {
    default_policy: CLASS_REJECT
    value_threshold: 0.95
    class_include: "1"
  }
}

# Remove the stalks outside the segmentation contour
stages {
  name: "stalk_inside"
  type: OVERLAP_FILTER
  input: "item"
  input: "stalk_filter"
  overlap_filter_param {
    threshold: 0.7
    inout: IN # IN, OUT
    reference: SHAPE # SHAPE, PATCH
    match_parents: true
  }
}

# Stalk ranking
stages {
  name: "stalk_hidden"
  type: RANKING
  input: "stalk_inside"
  ranking_param {
    class_rank_def: "1:1"
    group_by_root: true
  }
}

# Make the stalk an output stage
stages {
  name: "stalk"
  type: JOIN
  input: "stalk_hidden"
}

# Caliper evaluation
stages {
  name: "caliper"
  type: CALIPER
  input: "item"
  input: "stalk_hidden"
  caliper_param {
    cross_major_axis: $cross_major_axis # true
    #simmetry_ratio: 0.85
    #correction_policy: ZERO
  }
}


# Exclude all the classes except the flaws
stages {
  name: "flaw_candidate"
  type: RANKING
  input: "flaw_all"
  ranking_param {
    class_rank_def: "0:0, 1:0"
    group_by_root: true
  }
}

# Flaws filter based on values
stages {
  name: "flaw_filter"
  type: CLASS_FILTER
  input: "flaw_candidate"
  class_filter_param {
    value_threshold: 0.95
  }
}

# Remove the stalks outside the segmentation contour
stages {
  name: "flaw"
  type: OVERLAP_FILTER
  input: "item"
  input: "flaw_filter"
  overlap_filter_param {
    threshold: 0.7
    inout: IN # IN, OUT
    reference: SHAPE # SHAPE, PATCH
    match_parents: true
  }
}
